@@ -5,7 +5,7 @@ use v5.20;
 use experimental qw/ signatures /;
 package YAML::Tidy::Config;
 
-our $VERSION = '0.006_001'; # TRIAL VERSION
+our $VERSION = 'v0.8.0'; # VERSION
 
 use Cwd;
 use YAML::PP::Common qw/
@@ -77,6 +77,12 @@ sub new($class, %args) {
         my $default = $scalar->{default};
         $scalarstyle->{default} = $default ? $stylemap{ $default } : undef;
     }
+    my $serialize_aliases = 0;
+    if (my $aliases = $cfg->{aliases}) {
+        if ($aliases->{serialize}) {
+            $serialize_aliases = 1;
+        }
+    }
 
     delete @args{qw/ configfile configdata /};
     if (my @unknown = keys %args) {
@@ -90,6 +96,7 @@ sub new($class, %args) {
         footer => delete $cfg->{footer} // 'keep',
         adjacency => delete $cfg->{adjacency} // 'keep',
         scalar_style => $scalarstyle,
+        serialize_aliases => $serialize_aliases,
     }, $class;
     return $self;
 }
@@ -147,6 +154,22 @@ sub default_scalar_style($self) {
     return $self->{scalar_style}->{default};
 }
 
+# Turns
+#    ---
+#    - &color blue
+#    - *color
+#    - &color pink
+#    - *color
+#    ...
+# into
+#    ---
+#    - &color_1 blue
+#    - *blue_1
+#    - &color_2 blue
+#    - *blue_2
+#    ...
+sub serialize_aliases($self) { $self->{serialize_aliases} }
+
 sub standardcfg {
     my $yaml = <<'EOM';
 ---
